@@ -3,7 +3,7 @@ use 5.012;
 use strict;
 use warnings;
 use Carp;
-our $VERSION = "0.12";
+our $VERSION = "0.13";
 use Moo;
 use HTTP::Tiny '0.056';
 use JSON::Tiny qw[decode_json];
@@ -13,6 +13,7 @@ use namespace::clean;
 use DateTime;
 our $DEBUG = !1;
 require Data::Dump if $DEBUG;
+our $DEV = !1;
 #
 use lib '../../lib';
 use Finance::Robinhood::Account;
@@ -70,7 +71,11 @@ my %endpoints = (
 
 sub endpoint {
     $endpoints{$_[0]} ?
-        'https://api.robinhood.com/' . $endpoints{+shift}
+        ($DEV ?
+             'http://brokeback.dev.robinhood.com/'
+         : 'https://api.robinhood.com/'
+        )
+        . $endpoints{+shift}
         : ();
 }
 #
